@@ -2,7 +2,7 @@ use coreemu::Client;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let mut client = Client::connect("http://127.0.0.1:50051").await?;
+    let mut client = Client::connect("http://127.0.0.1:50051".into()).await?;
 
     let response = client.get_sessions().await?;
 
